@@ -160,7 +160,7 @@ print.etl <- function(x, ...) {
   file_info <- dplyr::bind_rows(
     summary_dir(attr(x, "raw_dir")),
     summary_dir(attr(x, "load_dir"))) %>%
-    summarize_(N = ~sum(n), size = ~sum(readr::parse_number(size)))
+    summarize(N = sum(n), size = sum(readr::parse_number(size)))
   cat("dir:  ", file_info$N, " files occupying ",
       file_info$size, " GB\n", sep = "")
   NextMethod()
